4.50. umbra.ui.widgets.active_QLabel — Umbra 1.0.4 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »

# 4.50. umbra.ui.widgets.active_QLabel

active_QLabel.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `Active_QLabel` class.

Others:

## 4.50.1. Module Attributes

`umbra.ui.widgets.active_QLabel.` `LOGGER`

## 4.50.2. Classes

class `umbra.ui.widgets.active_QLabel.` `Active_QLabel`(parent=None, defaultPixmap=None, hoverPixmap=None, activePixmap=None, checkable=False, checked=False)

  Bases: `PyQt4.QtGui.QLabel`

  This class is a QLabel subclass providing a clickable label with hovering capabilities.

  Parameters: | parent – Widget parent. ( QObject ) defaultPixmap – Label default pixmap. ( QPixmap ) hoverPixmap – Label hover pixmap. ( QPixmap ) activePixmap – Label active pixmap. ( QPixmap ) checkable – Checkable state. ( Boolean ) checked – Checked state. ( Boolean )

  `clicked`

    This signal is emited by the `Active_QLabel` class when it has been clicked. ( pyqtSignal )

  `pressed`

    This signal is emited by the `Active_QLabel` class when it has been pressed. ( pyqtSignal )

  `released`

    This signal is emited by the `Active_QLabel` class when it has been released. ( pyqtSignal )

  `toggled`

    This signal is emited by the `Active_QLabel` class when it has been toggled. ( pyqtSignal )

    Returns: | Current checked state. ( Boolean )

  `defaultPixmap`

    This method is the property for self.__defaultPixmap attribute.

    Returns: | self.__defaultPixmap. ( QPixmap )

  `hoverPixmap`

    This method is the property for self.__hoverPixmap attribute.

    Returns: | self.__hoverPixmap. ( QPixmap )

  `activePixmap`

    This method is the property for self.__activePixmap attribute.

    Returns: | self.__activePixmap. ( QPixmap )

  `checkable`

    This method is the property for self.__checkable attribute.

    Returns: | self.__checkable. ( Boolean )

  `checked`

    This method is the property for self.__checked attribute.

    Returns: | self.__checked. ( Boolean )

  `menu`

    This method is the property for self.__menu attribute.

    Returns: | self.__menu. ( QMenu )

  `enterEvent`(event)

    This method reimplements the `QLabel.enterEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `leaveEvent`(event)

    This method reimplements the `QLabel.leaveEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `mousePressEvent`(event)

    This method reimplements the `QLabel.mousePressEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `mouseReleaseEvent`(event)

    This method reimplements the `QLabel.mouseReleaseEvent()` method.

    Parameters: | event – QEvent. ( QEvent )

  `setChecked`(state)

    This method sets the Widget checked state.

    Parameters: | state – New check state. ( Boolean )
    Returns: | Method success. ( Boolean )

  `setMenu`(menu)

    This method sets the Widget menu.

    Parameters: | menu – Menu. ( QMenu )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.4 documentation »
- 4. Api »